module Fastlane
  module Actions
    module SharedValues
      GET_EMTITLEMENTS_PLIST_FILE_PATH_CUSTOM_VALUE = :GET_EMTITLEMENTS_PLIST_FILE_PATH_CUSTOM_VALUE
    end

    class GetEmtitlementsPlistFilePathAction < Action
      require 'xcodeproj'
      require 'pathname'

      def self.run(params)
        project = find_project(params)
        target = find_target(params)
        buildConfiguration = target.build_settings("Release")
        filePath = buildConfiguration["CODE_SIGN_ENTITLEMENTS"]
        if params[:is_absolute] then
          filePath = File.join(Pathname.new(project.path).parent.to_path, filePath)
        end
        filePath
      end

      def self.find_project(params)
        project = Xcodeproj::Project.open(params[:xcodeproj])
        project
      end

      def self.find_target(params)
        project = find_project(params)
        if params[:target]
          target = project.targets.detect { |t| t.name == params[:target] }
          target
        else
          # firstly we are trying to find modern application target
          target = project.targets.detect do |t|
            t.kind_of?(Xcodeproj::Project::Object::PBXNativeTarget) &&
              t.product_type == 'com.apple.product-type.application'
          end
          target = project.targets[0] if target.nil?
          target
        end
      end

      #####################################################
      # @!group Documentation
      #####################################################

      def self.description
        "A short description with <= 80 characters of what this action does"
      end

      def self.details
        # Optional:
        # this is your chance to provide a more detailed description of this action
        "You can use this action to do cool things..."
      end

      def self.available_options
        # Define all options your action supports. 
        
        # Below a few examples
        [
          FastlaneCore::ConfigItem.new(key: :api_token,
                                       env_name: "FL_GET_EMTITLEMENTS_PLIST_FILE_PATH_API_TOKEN", # The name of the environment variable
                                       description: "API Token for GetEmtitlementsPlistFilePathAction", # a short description of this parameter
                                       verify_block: proc do |value|
                                          UI.user_error!("No API token for GetEmtitlementsPlistFilePathAction given, pass using `api_token: 'token'`") unless (value and not value.empty?)
                                          # UI.user_error!("Couldn't find file at path '#{value}'") unless File.exist?(value)
                                       end),
          FastlaneCore::ConfigItem.new(key: :development,
                                       env_name: "FL_GET_EMTITLEMENTS_PLIST_FILE_PATH_DEVELOPMENT",
                                       description: "Create a development certificate instead of a distribution one",
                                       is_string: false, # true: verifies the input is a string, false: every kind of value
                                       default_value: false) # the default value if the user didn't provide one
        ]
      end
      def self.available_options
        # Define all options your action supports. 
        
        # Below a few examples
        [
          FastlaneCore::ConfigItem.new(key: :xcodeproj,
                                       env_name: "FL_GET_EMTITLEMENTS_PLIST_FILE_PATH_XCODEPROJ",
                                       description: "Optional, you must specify the path to your main Xcode project if it is not in the project root directory or if you have multiple *.xcodeproj's in the root directory",
                                       optional: true,
                                       verify_block: proc do |value|
                                        UI.user_error!("Please pass the path to the project, not the workspace") if value.end_with? ".xcworkspace"
                                        UI.user_error!("Could not find Xcode project at path '#{File.expand_path(value)}'") if !File.exist?(value) and !Helper.is_test?
                                      end),
          FastlaneCore::ConfigItem.new(key: :target,
                                      env_name: "FL_GET_EMTITLEMENTS_PLIST_FILE_PATH_TARGET",
                                      conflicting_options: [:scheme],
                                      description: "Specify a specific target if you have multiple per project, optional"),
          FastlaneCore::ConfigItem.new(key: :is_absolute,
                                       env_name: "FL_GET_EMTITLEMENTS_PLIST_FILE_PATH_IS_ABSOLUTE",
                                       description: "Specify a specific target if you have multiple per project, optional",
                                       optional: true,
                                       is_string: false,
                                       default_value: false)
        ]
      end

      def self.output
        # Define the shared values you are going to provide
        # Example
        [
          ['GET_EMTITLEMENTS_PLIST_FILE_PATH_CUSTOM_VALUE', 'A description of what this value contains']
        ]
      end

      def self.return_value
        # If your method provides a return value, you can describe here what it does
      end

      def self.authors
        # So no one will ever forget your contribution to fastlane :) You are awesome btw!
        ["Your GitHub/Twitter Name"]
      end

      def self.is_supported?(platform)
        # you can do things like
        # 
        #  true
        # 
        #  platform == :ios
        # 
        #  [:ios, :mac].include?(platform)
        # 

        platform == :ios
      end
    end
  end
end
