module Fastlane
  module Actions
    module SharedValues
      GET_EXTENSIONS_CUSTOM_VALUE = :GET_EXTENSIONS_CUSTOM_VALUE
    end

    class GetExtensionsAction < Action
      require 'xcodeproj'

      def self.run(params)
        

      end

      def self.find_project(params)
        project = Xcodeproj::Project.open(params[:xcodeproj])
        project
      end

      def self.find_target(params)
        project = find_project(params)
        if params[:target]
          target = project.targets.detect { |t| t.name == params[:target] }
          target
        else
          # firstly we are trying to find modern application target
          target = project.targets.detect do |t|
            t.kind_of?(Xcodeproj::Project::Object::PBXNativeTarget) &&
              t.product_type == 'com.apple.product-type.application'
          end
          target = project.targets[0] if target.nil?
          target
        end
      end

      def self.get_ci_apps(params)
        infoPlistPath = find_info(params)
        info = Xcodeproj::Plist.read_from_path(infoPlistPath)
        ciAPPs = info["CI_APPS"]
        ciAPPs
      end

      def self.get_ci_app(params)
        ciApps = get_ci_apps(params)
        ciApps.each do |app|
          if app["APP_ID"] == params[:app_id] then
            return app
          end
        end
      end

      #####################################################
      # @!group Documentation
      #####################################################

      def self.description
        "A short description with <= 80 characters of what this action does"
      end

      def self.details
        # Optional:
        # this is your chance to provide a more detailed description of this action
        "You can use this action to do cool things..."
      end

      def self.available_options
        # Define all options your action supports. 
        
        # Below a few examples
        [
          FastlaneCore::ConfigItem.new(key: :project,
                                       env_name: "FL_GET_EXTENSIONS_PROJECT_PATH", # The name of the environment variable
                                       description: "API Token for GetExtensionsAction", # a short description of this parameter
                                       verify_block: proc do |value|
                                          UI.user_error!("No API token for GetExtensionsAction given, pass using `api_token: 'token'`") unless (value and not value.empty?)
                                          # UI.user_error!("Couldn't find file at path '#{value}'") unless File.exist?(value)
                                       end),
          FastlaneCore::ConfigItem.new(key: :target,
                                       env_name: "FL_GET_EXTENSIONS_TARGET_NAME",
                                       description: "Create a development certificate instead of a distribution one",
                                       is_string: false, # true: verifies the input is a string, false: every kind of value
                                       default_value: false) # the default value if the user didn't provide one
        ]
      end

      def self.output
        # Define the shared values you are going to provide
        # Example
        [
          ['GET_EXTENSIONS_CUSTOM_VALUE', 'A description of what this value contains']
        ]
      end

      def self.return_value
        # If your method provides a return value, you can describe here what it does
      end

      def self.authors
        # So no one will ever forget your contribution to fastlane :) You are awesome btw!
        ["Your GitHub/Twitter Name"]
      end

      def self.is_supported?(platform)
        # you can do things like
        # 
        #  true
        # 
        #  platform == :ios
        # 
        #  [:ios, :mac].include?(platform)
        # 

        platform == :ios
      end
    end
  end
end
